@@ -291,17 +291,27 @@ wnck_pager_size_request  (GtkWidget      *widget,
   int size;
   int n_rows;
   int focus_width;
-  
+  WnckWorkspace *space;
+
   pager = WNCK_PAGER (widget);
   
   n_spaces = wnck_screen_get_workspace_count (pager->priv->screen);
 
   g_assert (pager->priv->n_rows > 0);
   spaces_per_row = (n_spaces + pager->priv->n_rows - 1) / pager->priv->n_rows;
- 
+  space = wnck_screen_get_workspace (pager->priv->screen, 0);
+  
   if (pager->priv->orientation == GTK_ORIENTATION_VERTICAL)
     {
-      screen_aspect = (double) gdk_screen_height () / (double) gdk_screen_width ();
+      if (space) {
+        screen_aspect =
+              (double) wnck_workspace_get_height (space) /
+              (double) wnck_workspace_get_width (space);
+      } else {
+        screen_aspect =
+              (double) wnck_screen_get_height (pager->priv->screen) /
+              (double) wnck_screen_get_width (pager->priv->screen);
+      }
 
       /* TODO: Handle WNCK_PAGER_DISPLAY_NAME for this case */
 
@@ -324,10 +334,16 @@ wnck_pager_size_request  (GtkWidget      *widget,
     }
   else
     {
-      screen_aspect =
-        (double) wnck_screen_get_width (pager->priv->screen) /
-        (double) wnck_screen_get_height (pager->priv->screen);
-      
+      if (space) {
+        screen_aspect =
+              (double) wnck_workspace_get_width (space) /
+              (double) wnck_workspace_get_height (space);
+      } else {
+        screen_aspect =
+              (double) wnck_screen_get_width (pager->priv->screen) /
+              (double) wnck_screen_get_height (pager->priv->screen);
+      }
+
       if (pager->priv->show_all_workspaces)
 	{
 	  size = pager->priv->workspace_size;
@@ -738,8 +754,16 @@ workspace_at_point (WnckPager *pager,
 			"focus-line-width", &focus_width,
 			NULL);
 
-  xthickness = focus_width + widget->style->xthickness;
-  ythickness = focus_width + widget->style->ythickness;
+  if (pager->priv->shadow_type != GTK_SHADOW_NONE)
+    {
+      xthickness = focus_width + widget->style->xthickness;
+      ythickness = focus_width + widget->style->ythickness;
+    }
+  else
+    {
+      xthickness = focus_width;
+      ythickness = focus_width;
+    }
 
   n_spaces = wnck_screen_get_workspace_count (pager->priv->screen);
   
@@ -750,33 +774,39 @@ workspace_at_point (WnckPager *pager,
       
       get_workspace_rect (pager, i, &rect);
 
-      if (pager->priv->shadow_type != GTK_SHADOW_NONE)
-	{
-	  /* If workspace is on the edge, pretend points on the frame
-	   * belong to the workspace.
-	   */
+      /* If workspace is on the edge, pretend points on the frame belong to the
+       * workspace.
+       * Else, pretend the right/bottom line separating two workspaces belong
+       * to the workspace.
+       */
+      GtkWidget *widget = GTK_WIDGET (pager);
 
-	  GtkWidget *widget = GTK_WIDGET (pager);
-
-	  if (rect.x == xthickness)
-	    {
-	      rect.x = 0;
-	      rect.width += xthickness;
-	    }
-	  if (rect.y == ythickness)
-	    {
-	      rect.y = 0;
-	      rect.height += ythickness;
-	    }
-	  if (rect.y + rect.height == widget->allocation.height - ythickness)
-	    {
-	      rect.height += ythickness;
-	    }
-	  if (rect.x + rect.width == widget->allocation.width - xthickness)
-	    {
-	      rect.width += xthickness;
-	    }
-	}
+      if (rect.x == xthickness)
+        {
+          rect.x = 0;
+          rect.width += xthickness;
+        }
+      if (rect.y == ythickness)
+        {
+          rect.y = 0;
+          rect.height += ythickness;
+        }
+      if (rect.y + rect.height == widget->allocation.height - ythickness)
+        {
+          rect.height += ythickness;
+        }
+      else
+        {
+          rect.height += 1;
+        }
+      if (rect.x + rect.width == widget->allocation.width - xthickness)
+        {
+          rect.width += xthickness;
+        }
+      else
+        {
+          rect.width += 1;
+        }
 
       if (POINT_IN_RECT (x, y, rect))
         {
